@@ -180,6 +180,11 @@ def slugify(s):
     return re.sub(r'[-]+', '-', slug)
 
 
+def is_github():
+    v = environ.get('GITHUB_ACTION', False)
+    return type(v) is not bool and v is False
+
+
 def map_github_action(config):
     config['ci_commit_ref_name'] = config.get('github_ref_name')
     config['ci_job_id'] = config.get('github_run_id')
@@ -203,7 +208,7 @@ def get_config(**kwargs):
     for key in kwargs:
         res.update({key.lower(): get_value(key, **kwargs)})
 
-    if res.get('github_action', False):
+    if is_github():
         map_github_action(res)
     res.update({'private_deploy_key': res.get('private_deploy_key', False)})
     img_name = generate_image_name('{0}_{1}'.format(
@@ -350,7 +355,8 @@ def check_credentials(config):
 
 
 def prepare(**kwargs):
-    check_env_vars(**kwargs)
+    if not is_github():
+        check_env_vars(**kwargs)
     config = get_config(**kwargs)
     check_credentials(config)
     return config
